ChatRoomType enum

An enumeration representing different types of chat rooms.

Inheritance
Available extensions

Values

oneToOne → const ChatRoomType

A one-on-one private chat between two users.

group → const ChatRoomType

A group chat involving multiple users.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isGroup bool
Returns true if the chat room type is group.
no setter
isOneToOne bool
Returns true if the chat room type is oneToOne.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ChatRoomType>
A constant List of the values in this enum, in order of their declaration.