ChatView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ChatView
Constructors
-
ChatView({Key? key, required ChatController chatController, TypeIndicatorConfiguration typeIndicatorConfig = const TypeIndicatorConfiguration(), StringMessageCallBack? onSendTap, EditMessageCallback? onEditTap, ProfileCircleConfiguration? profileCircleConfig, ChatBubbleConfiguration? chatBubbleConfig, RepliedMessageConfiguration? repliedMessageConfig, SwipeToReplyConfiguration? swipeToReplyConfig, ReplyPopupConfiguration? replyPopupConfig, ReactionPopupConfiguration? reactionPopupConfig, PaginationCallback? loadMoreData, Widget? loadingWidget, MessageConfiguration? messageConfig, ValueGetter<
bool> ? isLastPage, Widget? appBar, ChatBackgroundConfiguration? chatBackgroundConfig, ReplyMessageWithReturnWidget? sendMessageBuilder, VoidCallback? onChatListTap, required ChatViewState chatViewState, ChatViewStateConfiguration? chatViewStateConfig, FeatureActiveConfig featureActiveConfig = const FeatureActiveConfig(), SendMessageConfiguration sendMessageConfig = const SendMessageConfiguration(), Config? emojiPickerSheetConfig, CustomViewForReplyMessage? replyMessageBuilder, ReplySuggestionsConfig? replySuggestionsConfig, ScrollToBottomButtonConfig? scrollToBottomButtonConfig}) -
const
Properties
- appBar → Widget?
-
Provides parameter so user can assign ChatViewAppbar.
final
- chatBackgroundConfig → ChatBackgroundConfiguration
-
Allow user to give customisation to background of chat
final
- chatBubbleConfig → ChatBubbleConfiguration?
-
Provides configurations related to chat bubble such as padding, margin, max
width etc.
final
- chatController → ChatController
-
Provides controller for accessing few function for running chat.
final
- chatViewState → ChatViewState
-
Provides current state of chat.
final
- chatViewStateConfig → ChatViewStateConfiguration
-
Provides configuration for chat view state appearance and functionality.
final
- emojiPickerSheetConfig → Config?
-
Configuration for emoji picker sheet
final
- featureActiveConfig → FeatureActiveConfig
-
Provides configuration for turn on/off specific features.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isLastPage
→ ValueGetter<
bool> ? -
Provides flag if there is no more next data left in list.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loadingWidget → Widget?
-
Provides widget for loading view while pagination is enabled.
final
- loadMoreData → PaginationCallback?
-
Provides callback when user actions reaches to top and needs to load more
chat
final
- messageConfig → MessageConfiguration?
-
Allow user to giving customisation different types
messages.
final
- onChatListTap → VoidCallback?
-
Provides callback when user tap on chat list.
final
- onEditTap → EditMessageCallback?
-
Callback invoked when the user confirms an edit on a message.
Receives the original Message and the updated text.
final
- onSendTap → StringMessageCallBack?
-
Provides call back when user tap on send button in text field. It returns
message, reply message and message type.
final
- profileCircleConfig → ProfileCircleConfiguration?
-
Provides configuration related to user profile circle avatar.
final
- reactionPopupConfig → ReactionPopupConfiguration?
-
Provides configuration for reaction pop up appearance.
final
- repliedMessageConfig → RepliedMessageConfiguration?
-
Provides configuration for replied message view which is located upon chat
bubble.
final
- replyMessageBuilder → CustomViewForReplyMessage?
-
Provides a callback for the view when replying to message
final
- replyPopupConfig → ReplyPopupConfiguration?
-
Provides configuration for reply snack bar's appearance and options.
final
- replySuggestionsConfig → ReplySuggestionsConfig?
-
Suggestion Item Config
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollToBottomButtonConfig → ScrollToBottomButtonConfig?
-
Provides a configuration for scroll to bottom button config
final
- sendMessageBuilder → ReplyMessageWithReturnWidget?
-
Provides builder which helps you to make custom text field and functionality.
final
- sendMessageConfig → SendMessageConfiguration
-
Provides configuration of default text field in chat.
final
- swipeToReplyConfig → SwipeToReplyConfiguration?
-
Provides configurations related to swipe chat bubble which triggers
when user swipe chat bubble.
final
- typeIndicatorConfig → TypeIndicatorConfiguration
-
Allow user to giving customisation typing indicator.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ChatView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
closeReplyMessageView(
BuildContext context) → void -
getReplyMessage(
BuildContext context) → ReplyMessage?