EmojiMessageConfiguration class

Constructors

EmojiMessageConfiguration({EdgeInsetsGeometry? padding, TextStyle? textStyle, int? maxOutSideBubbleEmojis})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxOutSideBubbleEmojis int?
Maximum number of emojis to show outside the bubble for emoji-only messages.
final
padding EdgeInsetsGeometry?
Used for giving padding to emoji messages.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
Used for giving text style to emoji messages.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited