PlayerMode enum

Defines the audio player mode, controlling whether single or multiple audio files can be played simultaneously.

Inheritance
Available extensions

Values

single → const PlayerMode

Only one audio can be played at a time.

Note: Starting recording will stop any currently playing audio.

multi → const PlayerMode

Multiple audios can be played simultaneously.

Note: Starting recording will not affect any currently playing audio.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isMulti bool

Available on PlayerMode, provided by the PlayerModeExtension extension

Checks if the player mode is multi.
no setter
isSingle bool

Available on PlayerMode, provided by the PlayerModeExtension extension

Checks if the player mode is single.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PlayerMode>
A constant List of the values in this enum, in order of their declaration.