UserActiveStatus enum

An enumeration of user status.

Inheritance
Available extensions

Values

online → const UserActiveStatus

user is active

offline → const UserActiveStatus

user is inactive

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isOffline bool
is user active
no setter
isOnline bool
is user inactive
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UserActiveStatus>
A constant List of the values in this enum, in order of their declaration.